3.1.2. pypago.sections.GridSection — PyPAGO 1.0.1 documentation

# 3.1.2. pypago.sections.GridSection

class `pypago.sections.` `GridSection`(grid, section)

  Gridded section object

  `__init__`(grid, section)

    Parameters: | grid (pypago.grid.Grid) – Model grid section (list) – List of `pypago.sections.Section` objects

  Methods

  `__init__`(grid, section) |
  param pypago.grid.Grid grid:
  | Model grid
  `plotsecfaces`([axes]) | Draws a gridded section as ‘staircase’, with grid points as the x and y coordinates.

  `plotsecfaces`(axes=None, **kwargs)

    Draws a gridded section as ‘staircase’, with grid points as the x and y coordinates.

    Should be plotted on a map background that shows the mask variables. Must be used to check whether the all the dots associated with one section are on the same side of the line

    Parameters: | axes (matplotlib.axes.Axes) – The `matplotlib axes` instance where to draw the lines kwargs (dict) – Additional arguments to the plot function
    Returns: | The color of the line
    Return type: | list|str|unicode